%if 0%{?fedora} >= 12 || 0%{?rhel} >= 8
%global with_py3 1
%endif

%global pkgname ZODB

Name:           python-%{pkgname}
Version:        4.0.1
Release:        1%{?dist}
Summary:        Zope Object Database and persistence

License:        ZPLv2.1
URL:            http://www.zodb.org/
Source0:        https://pypi.python.org/packages/source/Z/%{pkgname}/%{pkgname}-%{version}.tar.gz
# Fix a python 3.4-specific test failure; see
# https://groups.google.com/forum/#!topic/zodb/-IXn-WcKOiw
Patch0:         %{name}-test.patch
BuildArch:      noarch

BuildRequires:  python-BTrees
BuildRequires:  python-devel
BuildRequires:  python-manuel
BuildRequires:  python-persistent
BuildRequires:  python-random2
BuildRequires:  python-setuptools
BuildRequires:  python-six
BuildRequires:  python-transaction
BuildRequires:  python-zc-lockfile
BuildRequires:  python-ZConfig
BuildRequires:  python-zdaemon
BuildRequires:  python-zodbpickle
BuildRequires:  python-zope-proxy
BuildRequires:  python-zope-testing

%if 0%{?with_py3}
BuildRequires:  python3-BTrees
BuildRequires:  python3-devel
BuildRequires:  python3-manuel
BuildRequires:  python3-persistent
BuildRequires:  python3-random2
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-transaction
BuildRequires:  python3-zc-lockfile
BuildRequires:  python3-ZConfig
BuildRequires:  python3-zdaemon
BuildRequires:  python3-zodbpickle
BuildRequires:  python3-zope-proxy
BuildRequires:  python3-zope-testing
%endif

Requires:       python-BTrees
Requires:       python-persistent
Requires:       python-setuptools
Requires:       python-six
Requires:       python-transaction
Requires:       python-zc-lockfile
Requires:       python-ZConfig
Requires:       python-zdaemon
Requires:       python-zodbpickle
Requires:       python-zope-proxy

%global common_desc                                                \
The ZODB package provides a set of tools for using the Zope Object \
Database (ZODB).

%description
%{common_desc}

%if 0%{?with_py3}
%package -n python3-%{pkgname}
Summary:        Zope Object Database and persistence
Requires:       python3-BTrees
Requires:       python3-persistent
Requires:       python3-setuptools
Requires:       python3-six
Requires:       python3-transaction
Requires:       python3-zc-lockfile
Requires:       python3-ZConfig
Requires:       python3-zdaemon
Requires:       python3-zodbpickle
Requires:       python3-zope-proxy

%description -n python3-%{pkgname}
%{common_desc}
%endif

%prep
%setup -q -c

# Remove prebuilt egg
rm -fr %{pkgname}-%{version}/src/%{pkgname}.egg-info

# Remove backup files
rm -f %{pkgname}-%{version}/src/%{pkgname}/*~

# Fix a test
sed -i 's/random/random2/' %{pkgname}-%{version}/src/ZODB/tests/testUtils.py

%if 0%{?with_py3}
# Prepare for a python3 build
cp -a %{pkgname}-%{version} python3-%{pkgname}-%{version}
%endif

# Fix a python 3.4-specific test failure
%patch0

%build
# Python 2 build
pushd %{pkgname}-%{version}
%{__python2} setup.py build
popd

%if 0%{?with_py3}
# Python 3 build
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py build
popd
%endif

%install
%if 0%{?with_py3}
# Python 3 install
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py install -O1 --skip-build --root %{buildroot}
popd
for bin in fsdump fsoids fsrefs fstail repozo; do
  mv %{buildroot}%{_bindir}/$bin %{buildroot}%{_bindir}/python3-${bin}
done

# Fix scripts
for script in \
  $(grep -l '^#!' %{buildroot}%{python3_sitelib}/%{pkgname}/scripts/*.py); do
  sed 's,%{_bindir}/python,&3,;s,%{_bindir}/env python.*,%{_bindir}/python3,' \
    $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done
%endif

# Python 2 install
pushd %{pkgname}-%{version}
%{__python2} setup.py install -O1 --skip-build --root %{buildroot}

# Fix scripts
for script in \
  $(grep -l '^#!' %{buildroot}%{python2_sitelib}/%{pkgname}/scripts/*.py); do
  sed 's,%{_bindir}/python,&2,;s,%{_bindir}/env python.*,%{_bindir}/python2,' \
    $script > $script.new
  touch -r $script $script.new
  mv -f $script.new $script
  chmod 0755 $script
done
popd

%check
# Python 2 tests
pushd %{pkgname}-%{version}
%{__python2} setup.py test
popd

%if 0%{?with_py3}
# Python 3 tests
pushd python3-%{pkgname}-%{version}
%{__python3} setup.py test
popd
%endif

%files
%license %{pkgname}-%{version}/COPYRIGHT.txt %{pkgname}-%{version}/LICENSE.txt
%doc %{pkgname}-%{version}/doc/storage.pdf %{pkgname}-%{version}/doc/*.txt
%{_bindir}/fsdump
%{_bindir}/fsoids
%{_bindir}/fsrefs
%{_bindir}/fstail
%{_bindir}/repozo
%{python2_sitelib}/%{pkgname}*

%if 0%{?with_py3}
%files -n python3-%{pkgname}
%license %{pkgname}-%{version}/COPYRIGHT.txt %{pkgname}-%{version}/LICENSE.txt
%doc %{pkgname}-%{version}/doc/storage.pdf %{pkgname}-%{version}/doc/*.txt
%{_bindir}/python3-fsdump
%{_bindir}/python3-fsoids
%{_bindir}/python3-fsrefs
%{_bindir}/python3-fstail
%{_bindir}/python3-repozo
%{python3_sitelib}/%{pkgname}*
%endif

%changelog
* Wed Aug  6 2014 Jerry James <loganjerry@gmail.com> - 4.0.1-1
- New upstream release

* Wed Jun 11 2014 Jerry James <loganjerry@gmail.com> - 4.0.0-1
- Initial RPM
